@@ -7,6 +7,7 @@ from logging import error
 
 import click
 import cornflow
+from cornflow.app import create_app
 from cornflow.commands import (
     access_init_command,
     create_user_with_role,
@@ -124,7 +125,7 @@ def init_cornflow_service():
 
     if external_application == 0:
         click.echo("Starting cornflow")
-        app = cornflow.create_app(environment, cornflow_db_conn)
+        app = create_app(environment, cornflow_db_conn)
         with app.app_context():
             path = f"{os.path.dirname(cornflow.__file__)}/migrations"
             migrate = Migrate(app=app, db=db, directory=path)
@@ -154,10 +155,11 @@ def init_cornflow_service():
             register_dag_permissions_command(open_deployment, verbose=True)
             update_schemas_command(airflow_url, airflow_user, airflow_pwd, verbose=True)
 
-            # execute gunicorn application
-            os.system(
-                "/usr/local/bin/gunicorn -c python:cornflow.gunicorn \"cornflow:create_app('$FLASK_ENV')\""
-            )
+        # execute gunicorn application
+        os.system(
+            "/usr/local/bin/gunicorn -c python:cornflow.gunicorn \"cornflow.app:create_app('$FLASK_ENV')\""
+        )
+
     elif external_application == 1:
         click.echo(f"Starting cornflow + {os.getenv('EXTERNAL_APP_MODULE')}")
         os.chdir("/usr/src/app")
